/*==============================================================================

FICHIER     : [dvdcopy.h]

DATE        : 2006/01/0005 21:32:02

CREATEUR    : [Linux!jef]

COMMENTAIRE :

================================================================================

==============================================================================*/

#ifndef __DVDCOPY_H__
#define __DVDCOPY_H__

/*@$#[dvdcopy.c] global proto. AutoProtoSigV1.1. date: 2009/02/04 23:17:23 */
#include "proto.h"
#ifdef __cplusplus
extern "C" {
#endif
/* dvdcopy.c */
int ScanDvd PROTO((GtkWidget *forme));
void UpdDefFactor PROTO((GtkWidget *forme, int noPisteVideo, AudioMap_t *audioMap, SubMap_t *subMap));
long long GetMenuSize PROTO((void));
int GetSubId PROTO((int noPisteVideo, int noPisteSub));
int GetAudioId PROTO((int noPisteVideo, int noPisteAudio));
int ScanPiste PROTO((GtkWidget *forme, int noPisteVideo));
long long TotalAudioSize PROTO((int noPisteVideo, int *pDuree));
long AudioSize PROTO((int noPisteVideo, int noPisteAudio, pgc_t *pgc));
void VisuDvdPiste PROTO((int noPisteVideo));
void VisuDvdStruct PROTO((char *path));
int ExecuteMkIsoFs PROTO((char *sysCmd));
#ifdef __cplusplus
}
#endif
/*@$% end of AutoProtoSigV1.1 (Dont remove this line) [-I ../include]*/
#endif	/* __DVDCOPY_H__ */

